==> deepin-shell-debug-1.0.3-1.1-x86_64.pkg.tar.zst: usr/src/debug/deepin-shell/dde-shell/panels/dock/tray/quickpanel/.qt/rcc/qrc_qmake_org_deepin_ds_dock_tray_quickpanel.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xfc,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x73,0x2e,0x64,0x6f,0x63,0x6b,0x2e,0x74,0x72,0x61,0x79,0x2e,0x71,0x75,
  0x69,0x63,0x6b,0x70,0x61,0x6e,0x65,0x6c,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,
  0x67,0x65,0x74,0x20,0x74,0x72,0x61,0x79,0x2d,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,
  0x6e,0x65,0x6c,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,0x75,
  0x67,0x69,0x6e,0x20,0x74,0x72,0x61,0x79,0x2d,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,
  0x6e,0x65,0x6c,0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x6f,0x72,
  0x67,0x5f,0x64,0x65,0x65,0x70,0x69,0x6e,0x5f,0x64,0x73,0x5f,0x64,0x6f,0x63,0x6b,
  0x5f,0x74,0x72,0x61,0x79,0x5f,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,0x6e,0x65,0x6c,
  0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,0x65,0x69,0x6e,0x66,0x6f,0x20,
  0x74,0x72,0x61,0x79,0x2d,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,0x6e,0x65,0x6c,0x2e,
  0x71,0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,
  0x3a,0x2f,0x6f,0x72,0x67,0x2f,0x64,0x65,0x65,0x70,0x69,0x6e,0x2f,0x64,0x73,0x2f,
  0x64,0x6f,0x63,0x6b,0x2f,0x74,0x72,0x61,0x79,0x2f,0x71,0x75,0x69,0x63,0x6b,0x70,
  0x61,0x6e,0x65,0x6c,0x2f,0xa,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,
  0x20,0x31,0x2e,0x30,0x20,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,0x2e,
  0x71,0x6d,0x6c,0xa,0x44,0x72,0x61,0x67,0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,
  0x20,0x44,0x72,0x61,0x67,0x49,0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,0xa,0x50,0x61,
  0x6e,0x65,0x6c,0x50,0x6c,0x75,0x67,0x69,0x6e,0x50,0x61,0x67,0x65,0x20,0x31,0x2e,
  0x30,0x20,0x50,0x61,0x6e,0x65,0x6c,0x50,0x6c,0x75,0x67,0x69,0x6e,0x50,0x61,0x67,
  0x65,0x2e,0x71,0x6d,0x6c,0xa,0x50,0x61,0x6e,0x65,0x6c,0x54,0x72,0x61,0x79,0x49,
  0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x50,0x61,0x6e,0x65,0x6c,0x54,0x72,0x61,
  0x79,0x49,0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,0xa,0x50,0x6c,0x75,0x67,0x69,0x6e,
  0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x50,0x6c,0x75,0x67,0x69,0x6e,0x49,
  0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,0xa,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,
  0x65,0x6c,0x4d,0x6f,0x64,0x65,0x6c,0x20,0x31,0x2e,0x30,0x20,0x51,0x75,0x69,0x63,
  0x6b,0x50,0x61,0x6e,0x65,0x6c,0x4d,0x6f,0x64,0x65,0x6c,0x2e,0x71,0x6d,0x6c,0xa,
  0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,0x50,0x61,0x67,0x65,0x20,0x31,
  0x2e,0x30,0x20,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,0x50,0x61,0x67,
  0x65,0x2e,0x71,0x6d,0x6c,0xa,0x53,0x75,0x62,0x50,0x6c,0x75,0x67,0x69,0x6e,0x50,
  0x61,0x67,0x65,0x20,0x31,0x2e,0x30,0x20,0x53,0x75,0x62,0x50,0x6c,0x75,0x67,0x69,
  0x6e,0x50,0x61,0x67,0x65,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // ds
  0x0,0x2,
  0x0,0x0,0x6,0xb3,
  0x0,0x64,
  0x0,0x73,
    // dock
  0x0,0x4,
  0x0,0x6,0xb5,0x9b,
  0x0,0x64,
  0x0,0x6f,0x0,0x63,0x0,0x6b,
    // tray
  0x0,0x4,
  0x0,0x7,0xb8,0x89,
  0x0,0x74,
  0x0,0x72,0x0,0x61,0x0,0x79,
    // quickpanel
  0x0,0xa,
  0xa,0x29,0x93,0x5c,
  0x0,0x71,
  0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x70,0x0,0x61,0x0,0x6e,0x0,0x65,0x0,0x6c,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,
  // :/org/deepin/ds
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,
  // :/org/deepin/ds/dock
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,
  // :/org/deepin/ds/dock/tray
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,
  // :/org/deepin/ds/dock/tray/quickpanel
  0x0,0x0,0x0,0x44,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,
  // :/org/deepin/ds/dock/tray/quickpanel/qmldir
  0x0,0x0,0x0,0x5e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0xa2,0xa3,0xb1,0x28,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_ds_dock_tray_quickpanel)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_ds_dock_tray_quickpanel)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_ds_dock_tray_quickpanel)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_ds_dock_tray_quickpanel)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_ds_dock_tray_quickpanel)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_ds_dock_tray_quickpanel)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-shell-debug-1.0.4-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-shell/dde-shell/panels/dock/tray/quickpanel/.qt/rcc/qrc_qmake_org_deepin_ds_dock_tray_quickpanel.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xfc,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x73,0x2e,0x64,0x6f,0x63,0x6b,0x2e,0x74,0x72,0x61,0x79,0x2e,0x71,0x75,
  0x69,0x63,0x6b,0x70,0x61,0x6e,0x65,0x6c,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,
  0x67,0x65,0x74,0x20,0x74,0x72,0x61,0x79,0x2d,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,
  0x6e,0x65,0x6c,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,0x75,
  0x67,0x69,0x6e,0x20,0x74,0x72,0x61,0x79,0x2d,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,
  0x6e,0x65,0x6c,0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x6f,0x72,
  0x67,0x5f,0x64,0x65,0x65,0x70,0x69,0x6e,0x5f,0x64,0x73,0x5f,0x64,0x6f,0x63,0x6b,
  0x5f,0x74,0x72,0x61,0x79,0x5f,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,0x6e,0x65,0x6c,
  0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,0x65,0x69,0x6e,0x66,0x6f,0x20,
  0x74,0x72,0x61,0x79,0x2d,0x71,0x75,0x69,0x63,0x6b,0x70,0x61,0x6e,0x65,0x6c,0x2e,
  0x71,0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,
  0x3a,0x2f,0x6f,0x72,0x67,0x2f,0x64,0x65,0x65,0x70,0x69,0x6e,0x2f,0x64,0x73,0x2f,
  0x64,0x6f,0x63,0x6b,0x2f,0x74,0x72,0x61,0x79,0x2f,0x71,0x75,0x69,0x63,0x6b,0x70,
  0x61,0x6e,0x65,0x6c,0x2f,0xa,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,
  0x20,0x31,0x2e,0x30,0x20,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,0x2e,
  0x71,0x6d,0x6c,0xa,0x44,0x72,0x61,0x67,0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,
  0x20,0x44,0x72,0x61,0x67,0x49,0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,0xa,0x50,0x61,
  0x6e,0x65,0x6c,0x50,0x6c,0x75,0x67,0x69,0x6e,0x50,0x61,0x67,0x65,0x20,0x31,0x2e,
  0x30,0x20,0x50,0x61,0x6e,0x65,0x6c,0x50,0x6c,0x75,0x67,0x69,0x6e,0x50,0x61,0x67,
  0x65,0x2e,0x71,0x6d,0x6c,0xa,0x50,0x61,0x6e,0x65,0x6c,0x54,0x72,0x61,0x79,0x49,
  0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x50,0x61,0x6e,0x65,0x6c,0x54,0x72,0x61,
  0x79,0x49,0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,0xa,0x50,0x6c,0x75,0x67,0x69,0x6e,
  0x49,0x74,0x65,0x6d,0x20,0x31,0x2e,0x30,0x20,0x50,0x6c,0x75,0x67,0x69,0x6e,0x49,
  0x74,0x65,0x6d,0x2e,0x71,0x6d,0x6c,0xa,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,
  0x65,0x6c,0x4d,0x6f,0x64,0x65,0x6c,0x20,0x31,0x2e,0x30,0x20,0x51,0x75,0x69,0x63,
  0x6b,0x50,0x61,0x6e,0x65,0x6c,0x4d,0x6f,0x64,0x65,0x6c,0x2e,0x71,0x6d,0x6c,0xa,
  0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,0x50,0x61,0x67,0x65,0x20,0x31,
  0x2e,0x30,0x20,0x51,0x75,0x69,0x63,0x6b,0x50,0x61,0x6e,0x65,0x6c,0x50,0x61,0x67,
  0x65,0x2e,0x71,0x6d,0x6c,0xa,0x53,0x75,0x62,0x50,0x6c,0x75,0x67,0x69,0x6e,0x50,
  0x61,0x67,0x65,0x20,0x31,0x2e,0x30,0x20,0x53,0x75,0x62,0x50,0x6c,0x75,0x67,0x69,
  0x6e,0x50,0x61,0x67,0x65,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // ds
  0x0,0x2,
  0x0,0x0,0x6,0xb3,
  0x0,0x64,
  0x0,0x73,
    // dock
  0x0,0x4,
  0x0,0x6,0xb5,0x9b,
  0x0,0x64,
  0x0,0x6f,0x0,0x63,0x0,0x6b,
    // tray
  0x0,0x4,
  0x0,0x7,0xb8,0x89,
  0x0,0x74,
  0x0,0x72,0x0,0x61,0x0,0x79,
    // quickpanel
  0x0,0xa,
  0xa,0x29,0x93,0x5c,
  0x0,0x71,
  0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x70,0x0,0x61,0x0,0x6e,0x0,0x65,0x0,0x6c,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,
  // :/org/deepin/ds
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,
  // :/org/deepin/ds/dock
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,
  // :/org/deepin/ds/dock/tray
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,
  // :/org/deepin/ds/dock/tray/quickpanel
  0x0,0x0,0x0,0x44,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,
  // :/org/deepin/ds/dock/tray/quickpanel/qmldir
  0x0,0x0,0x0,0x5e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x94,0x6f,0xb8,0x1e,0x88,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_ds_dock_tray_quickpanel)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_ds_dock_tray_quickpanel)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_ds_dock_tray_quickpanel)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_ds_dock_tray_quickpanel)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_ds_dock_tray_quickpanel)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_ds_dock_tray_quickpanel)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
